@@ -229,6 +229,9 @@ pub struct Opt {
 	/// Sorts the tags topologically.
 	#[arg(long, help_heading = Some("FLAGS"))]
 	pub topo_order:       bool,
+	/// Include only the tags that belong to the current branch.
+	#[arg(long, help_heading = Some("FLAGS"))]
+	pub use_branch_tags:  bool,
 	/// Disables the external command execution.
 	#[arg(long, help_heading = Some("FLAGS"))]
 	pub no_exec:          bool,
@@ -301,7 +304,7 @@ pub struct Opt {
 		hide = !cfg!(feature = "gitea"),
 	)]
 	pub gitea_token:      Option<SecretString>,
-	/// Sets the GitLab repository.
+	/// Sets the Gitea repository.
 	#[arg(
 		long,
 		env = "GITEA_REPO",
@@ -446,7 +449,7 @@ mod tests {
 
 	#[test]
 	fn verify_cli() {
-		Opt::command().debug_assert()
+		Opt::command().debug_assert();
 	}
 
 	#[test]
